Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DelayedQuit ¶
DelayedQuit delays the QuitSignal so that any UI updates can happen before the binary is stopped.
Types ¶
type LogView ¶
type LogView struct {
// contains filtered or unexported fields
}
LogView handles creating the logs portion of the UI.
func NewLogView ¶
func NewLogView() *LogView
NewLogView creates a LogView with appropriate defaults.
type QuitSignal ¶
type QuitSignal struct{}
type ServiceView ¶
type ServiceView struct {
// contains filtered or unexported fields
}
ServiceView handles creating the services portion of the UI.
func NewServiceView ¶
func NewServiceView() *ServiceView
NewServiceView creates a ServiceView with appropriate defaults.
func (*ServiceView) Resize ¶
func (v *ServiceView) Resize(width, height int)
Resize sets the width/height of the ServiceView.
func (*ServiceView) Update ¶
func (v *ServiceView) Update(msg app.ServiceMessage)
Update ServiceView with data needed for View.
func (*ServiceView) UpdateStatus ¶
func (v *ServiceView) UpdateStatus(msg app.ServiceStatus)
UpdateStatus handles changes in status based on app.ServiceStatus.
func (*ServiceView) View ¶
func (v *ServiceView) View() string
View combines all of ServiceView's data into a string used by the parent View.
type UI ¶
type UI struct {
// contains filtered or unexported fields
}
UI handles creating all parts of the user interface.
func (*UI) SetCancel ¶
func (ui *UI) SetCancel(cancel func())
SetCancel makes the context.Context cancel function available to the UI.
func (*UI) SetContext ¶
SetContext makes the app.Context available to the UI.